//************************************************************
//
// eventID.h
//
/*! @file eventID.h
 *
 * @brief Event IDs.
 *
 * Define all event IDs we use at Telemotive.
 */
//************************************************************

#ifndef __EVENTID_H__
#define __EVENTID_H__

#if defined(__cplusplus)
#include <iostream>
#endif


enum eventid_t
{
    EVID_NOT_SET = 0,
    /* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     * Start of the reserved RDB event sections.
     * All event ids within this section are RDB relevant.
     * !!! PLEASE do not insert general bpng events here !!!!!
     * --------------------------------------------------*/
    EVID_STARTUP =0x01,                 //!< bpng start up
    EVID_SHUTDOWN = 0x02,               //!< bpng shut down
    EVID_MARKER = 0x03,                 //!< Marker set
    EVID_MARKER_CLEAR = 0x04,           //!< All Markers are deleted
    EVID_INFO = 0x05,                   //!< Info is set
    EVID_SLAVE_OFFSET = 0x06,           //!< cascading slave offset
    EVID_SLAVE_TO_MASTER = 0x07,        //!< cascading slave to master
    EVID_DATA_DELETED = 0x08,           //!< All data and data space is deleted
    EVID_TIME_SET =0x09,                //!< bpng time was set
    EVID_NEW_TIME = 0x0A,               //!< new time
    EVID_SUDDEN_DEATH = 0x0B,       //!< no "real" shutdown was found after startup.
    // ------------------------------------------------

#ifndef BPNGCLIENTLIB_EXPORTS
	// End of the reserved RDB event section
    EVID_RDB_SEC_END = 30, //!< only for dynamic limit handling
    // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    // ------------------------------------------------

    // Start of the general NG Event section
    // Here you can insert gernell bpng Events
    EVID_FILE_DELETED,  //!< Only one file is deleted
    EVID_ROT_PLUS,
    EVID_ROT_MINUS,
    EVID_MENU,
    EVID_ESC,
    EVID_DEFAULT_NETCONFIG ,
#endif
    EVID_INVALID = -1
};

#if defined(__cplusplus)
extern std::ostream &operator<< (std::ostream &os, eventid_t id);
extern eventid_t tmlibGetEventId(std::string _eventIdString);
#endif

#endif
